@@ -1,5 +1,5 @@
 library(testthat)
 library(mpMap2)
 
-omp_set_num_threads(1)
+try(omp_set_num_threads(1), silent = TRUE)
 test_check("mpMap2")
